==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Misc/MiscDraw/Counter/ts/Counter_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Counter</name>
    <message>
        <location filename="../Counter.js" line="+64"/>
        <source>Position</source>
        <translation>Pozicija</translation>
    </message>
    <message>
        <location filename="../Counter.ui" line="+17"/>
        <source>Start:</source>
        <translation>Začetek:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Incr:</source>
        <translation>Korak:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Precision:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Number of decimal digits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Prefix:</source>
        <translation>Predpona:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Suffix:</source>
        <translation>Pripona:</translation>
    </message>
    <message>
        <location filename="../CounterInit.js" line="+2"/>
        <source>&amp;Counter</source>
        <translation>&amp;Števec</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Auto increment number</source>
        <translation>Številka samodejnega koraka</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Misc/MiscDraw/Counter/ts/Counter_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Counter</name>
    <message>
        <location filename="../Counter.js" line="+64"/>
        <source>Position</source>
        <translation>Pozicija</translation>
    </message>
    <message>
        <location filename="../Counter.ui" line="+17"/>
        <source>Start:</source>
        <translation>Začetek:</translation>
    </message>
    <message>
        <source>Incr:</source>
        <translation type="vanished">Korak:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Increment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Precision:</source>
        <translation>Natančnost:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Number of decimal digits</source>
        <translation>Število decimalnih mest</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Prefix:</source>
        <translation>Predpona:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Suffix:</source>
        <translation>Pripona:</translation>
    </message>
    <message>
        <location filename="../CounterInit.js" line="+2"/>
        <source>&amp;Counter</source>
        <translation>&amp;Števec</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Auto increment number</source>
        <translation>Številka samodejnega koraka</translation>
    </message>
</context>
</TS>
